@@ -4,10 +4,10 @@
 # This work is licensed under the GNU GPLv2 or later.
 # See the COPYING file in the top-level directory.
 
-import logging
-
 from gi.repository import Gtk
 
+from virtinst import log
+
 from .asyncjob import vmmAsyncJob
 
 
@@ -69,6 +69,7 @@ class VMShutdownMenu(_VMMenu):
         self._add_action(_("Sa_ve"), "save", VMActionUI.save,
                 iconname=Gtk.STOCK_SAVE)
 
+        self.get_accessible().set_name("vmm-shutdown-menu")
         self.show_all()
 
     def update_widget_states(self, vm):
@@ -85,14 +86,6 @@ class VMShutdownMenu(_VMMenu):
             if name in statemap:
                 child.set_sensitive(statemap[name])
 
-            if name == "reset":
-                child.set_tooltip_text(None)
-                if vm and not vm.conn.check_support(
-                        vm.conn.SUPPORT_CONN_DOMAIN_RESET):
-                    child.set_tooltip_text(_("Hypervisor does not support "
-                        "domain reset."))
-                    child.set_sensitive(False)
-
 
 class VMActionMenu(_VMMenu):
     """
@@ -121,6 +114,7 @@ class VMActionMenu(_VMMenu):
             self._add_action(Gtk.STOCK_OPEN, "show",
                 VMActionUI.show, iconname=None)
 
+        self.get_accessible().set_name("vm-action-menu")
         self.show_all()
 
     def update_widget_states(self, vm):
@@ -130,7 +124,7 @@ class VMActionMenu(_VMMenu):
             "suspend": bool(vm and vm.is_stoppable()),
             "resume": bool(vm and vm.is_paused()),
             "migrate": bool(vm and vm.is_stoppable()),
-            "clone": bool(vm and vm.is_clonable()),
+            "clone": bool(vm and vm.is_cloneable()),
         }
         vismap = {
             "suspend": bool(vm and not vm.is_paused()),
@@ -160,19 +154,18 @@ class VMActionUI(object):
 
     @staticmethod
     def save_cancel(asyncjob, vm):
-        logging.debug("Cancelling save job")
+        log.debug("Cancelling save job")
         if not vm:
-            return
+            return  # pragma: no cover
 
         try:
             vm.abort_job()
         except Exception as e:
-            logging.exception("Error cancelling save job")
+            log.exception("Error cancelling save job")
             asyncjob.show_warning(_("Error cancelling save job: %s") % str(e))
             return
 
-        asyncjob.job_canceled = True
-        return
+        asyncjob.job_canceled = True  # pragma: no cover
 
     @staticmethod
     def save(src, vm):
@@ -182,13 +175,13 @@ class VMActionUI(object):
             return
 
         _cancel_cb = None
-        if vm.getjobinfo_supported:
+        if vm.supports_domain_job_info():
             _cancel_cb = (VMActionUI.save_cancel, vm)
 
         def cb(asyncjob):
             vm.save(meter=asyncjob.get_meter())
         def finish_cb(error, details):
-            if error is not None:
+            if error is not None:  # pragma: no cover
                 error = _("Error saving domain: %s") % error
                 src.err.show_err(error, details=details)
 
@@ -210,7 +203,7 @@ class VMActionUI(object):
                     "shutting down the OS and may cause data loss.")):
             return
 
-        logging.debug("Destroying vm '%s'", vm.get_name())
+        log.debug("Destroying vm '%s'", vm.get_name())
         vmmAsyncJob.simple_async_noshow(vm.destroy, [], src,
                                         _("Error shutting down domain"))
 
@@ -222,25 +215,25 @@ class VMActionUI(object):
                     vm.get_name())):
             return
 
-        logging.debug("Pausing vm '%s'", vm.get_name())
+        log.debug("Pausing vm '%s'", vm.get_name())
         vmmAsyncJob.simple_async_noshow(vm.suspend, [], src,
                                         _("Error pausing domain"))
 
     @staticmethod
     def resume(src, vm):
-        logging.debug("Unpausing vm '%s'", vm.get_name())
+        log.debug("Unpausing vm '%s'", vm.get_name())
         vmmAsyncJob.simple_async_noshow(vm.resume, [], src,
                                         _("Error unpausing domain"))
 
     @staticmethod
     def run(src, vm):
-        logging.debug("Starting vm '%s'", vm.get_name())
+        log.debug("Starting vm '%s'", vm.get_name())
 
         if vm.has_managed_save():
             def errorcb(error, details):
                 # This is run from the main thread
                 res = src.err.show_err(
-                    _("Error restoring domain") + ": " + error,
+                    _("Error restoring domain: %s") % error,
                     details=details,
                     text2=_(
                         "The domain could not be restored. Would you like\n"
@@ -256,7 +249,7 @@ class VMActionUI(object):
                 try:
                     vm.remove_saved_image()
                     VMActionUI.run(src, vm)
-                except Exception as e:
+                except Exception as e:  # pragma: no cover
                     src.err.show_err(_("Error removing domain state: %s")
                                      % str(e))
 
@@ -279,7 +272,7 @@ class VMActionUI(object):
                     vm.get_name())):
             return
 
-        logging.debug("Shutting down vm '%s'", vm.get_name())
+        log.debug("Shutting down vm '%s'", vm.get_name())
         vmmAsyncJob.simple_async_noshow(vm.shutdown, [], src,
                                         _("Error shutting down domain"))
 
@@ -291,7 +284,7 @@ class VMActionUI(object):
                     vm.get_name())):
             return
 
-        logging.debug("Rebooting vm '%s'", vm.get_name())
+        log.debug("Rebooting vm '%s'", vm.get_name())
         vmmAsyncJob.simple_async_noshow(vm.reboot, [], src,
             _("Error rebooting domain"))
 
@@ -306,7 +299,7 @@ class VMActionUI(object):
                     "shutting down the OS and may cause data loss.")):
             return
 
-        logging.debug("Resetting vm '%s'", vm.get_name())
+        log.debug("Resetting vm '%s'", vm.get_name())
         vmmAsyncJob.simple_async_noshow(vm.reset, [], src,
                                         _("Error resetting domain"))
 
@@ -327,5 +320,5 @@ class VMActionUI(object):
 
     @staticmethod
     def show(src, vm):
-        from .details import vmmDetails
-        vmmDetails.get_instance(src, vm).show()
+        from .vmwindow import vmmVMWindow
+        vmmVMWindow.get_instance(src, vm).show()
